@@ -1,11 +1,11 @@
 import json
 import requests
 
-from common.configuration.httpClientConfig import HttpClientConfig
-from common.dto.logCreateDto import LogCreateDto
-from common.dto.logRequestDto import LogRequestDto
-from common.enums.logLevel import LogLevel
-from common.enums.platform import Platform
+from logger.src.common.configuration.httpClientConfig import HttpClientConfig
+from logger.src.common.dto.logCreateDto import LogCreateDto
+from logger.src.common.dto.logRequestDto import LogRequestDto
+from logger.src.common.enums.logLevel import LogLevel
+from logger.src.common.enums.platform import Platform
 
 with requests.Session() as session:
     session.headers.update({
